@@ -44,13 +44,13 @@ func (l *CreateTester) Run(cluster *base.ClusterContext) (stdout string, stderr
 	log.Printf("Validating 'skupper link create'")
 
 	// Preparing regex to validate output
-	connectionNameRegex := "conn[0-9]+"
+	connectionNameRegex := "link[0-9]+"
 	if l.Name != "" {
 		connectionNameRegex = l.Name
 	}
 
 	// Example: Skupper configured to connect to 10.0.0.1:45671 (name=conn1)
-	outRegex := regexp.MustCompile(fmt.Sprintf(`Skupper configured to connect to .* \(name=%s\)`, connectionNameRegex))
+	outRegex := regexp.MustCompile(fmt.Sprintf(`Site configured to link to .* \(name=%s\)`, connectionNameRegex))
 
 	// Ensure stdout matches expected regexp
 	if !outRegex.MatchString(stdout) {
